@@ -33,12 +33,25 @@ from nose.tools import (
     assert_equal,
     assert_almost_equal,
     assert_raises,
+    assert_true,
+)
+from distributions.dbg.random import (
+    sample_stick,
+    sample_discrete_log,
+    sample_inverse_wishart,
+    score_student_t as dbg_score_student_t,
+)
+from distributions.lp.random import (
+    score_student_t as lp_score_student_t,
+)
+from distributions.dbg.models.nich import (
+    score_student_t as scalar_score_student_t,
 )
-from distributions.dbg.random import sample_stick, sample_discrete_log
 from distributions.tests.util import (
     require_cython,
     assert_close,
     assert_samples_match_scores,
+    seed_all,
 )
 
 
@@ -170,17 +183,13 @@ def test_sample_pair_from_urn():
 def test_prob_from_scores():
     require_cython()
     import distributions.lp.random
-    rng1 = distributions.lp.random.RNG(0)
-    rng2 = distributions.lp.random.RNG(0)
     for size in range(1, 100):
         scores = numpy.random.normal(size=size).tolist()
         for _ in xrange(size):
             sample, prob1 = distributions.lp.random.sample_prob_from_scores(
-                rng1,
                 scores)
             assert 0 <= sample and sample < size
             prob2 = distributions.lp.random.prob_from_scores(
-                rng2,
                 sample,
                 scores)
             assert_close(
@@ -192,12 +201,11 @@ def test_prob_from_scores():
 def test_sample_prob_from_scores():
     require_cython()
     import distributions.lp.random
-    rng = distributions.lp.random.RNG(0)
     for size in range(1, 10):
         scores = numpy.random.normal(size=size).tolist()
 
         def sampler():
-            return distributions.lp.random.sample_prob_from_scores(rng, scores)
+            return distributions.lp.random.sample_prob_from_scores(scores)
 
         assert_samples_match_scores(sampler)
 
@@ -211,3 +219,108 @@ def test_log_sum_exp():
         expected = numpy.logaddexp.reduce(scores) if size else 0.0
         actual = distributions.lp.random.log_sum_exp(scores)
         assert_close(actual, expected, err_msg='log_sum_exp')
+
+
+def test_sample_discrete():
+    require_cython()
+    import distributions.lp.random
+
+    assert_equal(
+        distributions.lp.random.sample_discrete(
+            numpy.array([.5], dtype=numpy.float32)),
+        0)
+    assert_equal(
+        distributions.lp.random.sample_discrete(
+            numpy.array([1.], dtype=numpy.float32)),
+        0)
+    assert_equal(
+        distributions.lp.random.sample_discrete(
+            numpy.array([1e-3], dtype=numpy.float32)),
+        0)
+    assert_equal(
+        distributions.lp.random.sample_discrete(
+            numpy.array([1 - 1e-3, 1e-3], dtype=numpy.float32)),
+        0)
+    assert_equal(
+        distributions.lp.random.sample_discrete(
+            numpy.array([1e-3, 1 - 1e-3], dtype=numpy.float32)),
+        1)
+
+
+def random_orthogonal_matrix(m, n):
+    A, _ = numpy.linalg.qr(numpy.random.random((m, n)))
+    return A
+
+
+def random_orthonormal_matrix(n):
+    A = random_orthogonal_matrix(n, n)
+    return A
+
+
+def test_sample_iw():
+
+    Q = random_orthonormal_matrix(2)
+    nu = 4
+    S = numpy.dot(Q, numpy.dot(numpy.diag([1.0, 0.5]), Q.T))
+
+    true_mean = 1. / (nu - S.shape[0] - 1) * S
+
+    ntries = 100
+    samples = []
+    while ntries:
+        samples.extend([sample_inverse_wishart(nu, S) for _ in xrange(10000)])
+        mean = sum(samples) / len(samples)
+        diff = numpy.linalg.norm(true_mean - mean)
+        if diff <= 0.1:
+            return
+        ntries -= 1
+
+    assert_true(False, "mean did not converge")
+
+
+def test_score_student_t_scalar_equiv():
+    values = (
+        (1.2, 5., -0.2, 0.7),
+        (-3., 3., 1.2, 1.3),
+    )
+    for x, nu, mu, sigmasq in values:
+        mv_args = [
+            numpy.array([x]),
+            nu,
+            numpy.array([mu]),
+            numpy.array([[sigmasq]])]
+
+        scalar_score = scalar_score_student_t(x, nu, mu, sigmasq)
+        dbg_mv_score = dbg_score_student_t(*mv_args)
+        lp_mv_score = lp_score_student_t(*mv_args)
+
+        assert_close(scalar_score, dbg_mv_score)
+        assert_close(scalar_score, lp_mv_score)
+        assert_close(dbg_mv_score, lp_mv_score)
+
+
+def test_score_student_t_dbg_lp_equiv():
+    seed_all(0)
+
+    def random_vec(dim):
+        return numpy.random.uniform(low=-3., high=3., size=dim)
+
+    def random_cov(dim):
+        Q = random_orthonormal_matrix(dim)
+        return numpy.dot(Q, Q.T)
+
+    def random_values(dim):
+        return (random_vec(dim),
+                float(dim) + 1.,
+                random_vec(dim),
+                random_cov(dim))
+
+    values = (
+        [random_values(2) for _ in xrange(10)] +
+        [random_values(3) for _ in xrange(10)]
+    )
+
+    for x, nu, mu, cov in values:
+        dbg_mv_score = dbg_score_student_t(x, nu, mu, cov)
+        lp_mv_score = lp_score_student_t(x, nu, mu, cov)
+        assert_close(dbg_mv_score, lp_mv_score)
